#athena workgroup
resource "aws_athena_workgroup" "athena_workgroup" {
  name = var.workgroup_name

  configuration {
    enforce_workgroup_configuration    = true
    publish_cloudwatch_metrics_enabled = true

    result_configuration {
      output_location = "s3://${var.result_location}"

      encryption_configuration {
        encryption_option = "SSE_S3"
      }

    }
  }
  force_destroy = true
  tags          = var.tags
}

resource "aws_iam_policy" "read-only-policy" {
  count       = var.enable_iam_policies ? 1 : 0
  name        = "${var.iam_policy_prefix}-athena-read-only"
  path        = "/"
  description = "Athena read-only policy"

  policy = <<EOF
{
    "Version": "2012-10-17",
    "Statement": [
        {
            "Effect": "Allow",
            "Action": [
                "athena:Get*",
                "athena:List*",
                "athena:BatchGet*"
            ],
            "Resource": [
                "${aws_athena_workgroup.athena_workgroup.arn}"
            ]
        }       
    ]
}
EOF
  lifecycle {
    ignore_changes = [
      description,
    ]
  }

  tags = var.tags
}

resource "aws_iam_policy" "read-write-policy" {
  count       = var.enable_iam_policies ? 1 : 0
  name        = "${var.iam_policy_prefix}-athena-read-write"
  path        = "/"
  description = "Athena read and write policy"

  policy = <<EOF
{
    "Version": "2012-10-17",
    "Statement": [
        {
            "Effect": "Allow",
            "Action": [
                "athena:Get*",
                "athena:List*",
                "athena:Update*",
                "athena:Batch*",
                "athena:StartQuery*",
                "athena:StopQuery*"
            ],
            "Resource": [
                "${aws_athena_workgroup.athena_workgroup.arn}"
            ]
        }
    ]
}
EOF
  lifecycle {
    ignore_changes = [
      description,
    ]
  }

  tags = var.tags
}
